pub enum FreezeCommand {
    Initialize {
        keypair: Option<String>,
        rpc_url: Option<String>,
        cache: String,
        config: String,
        candy_guard: Option<String>,
        candy_machine: Option<String>,
        destination: Option<String>,
        label: Option<String>,
    },
    Thaw {
        keypair: Option<String>,
        rpc_url: Option<String>,
        cache: String,
        config: String,
        all: bool,
        nft_mint: Option<String>,
        candy_guard: Option<String>,
        candy_machine: Option<String>,
        destination: Option<String>,
        label: Option<String>,
        use_cache: bool,
        timeout: Option<u64>,
    },
    UnlockFunds {
        keypair: Option<String>,
        rpc_url: Option<String>,
        cache: String,
        config: String,
        candy_guard: Option<String>,
        candy_machine: Option<String>,
        destination: Option<String>,
        label: Option<String>,
    },
}

Variants



Initialize

Fields

keypair: Option<String>

Path to the keypair file, uses Sol config or defaults to “~/.config/solana/id.json”

rpc_url: Option<String>

RPC Url

cache: String

Path to the cache file, defaults to “cache.json”

config: String

Path to the config file

candy_guard: Option<String>

Address of candy guard to update [defaults to cache value].

candy_machine: Option<String>

Address of candy machine to update [defaults to cache value].

destination: Option<String>

Address of the destination (treasury) account.

label: Option<String>

Candy guard group label.

Initialize the freeze escrow account.



Thaw

Fields

keypair: Option<String>

Path to the keypair file, uses Sol config or defaults to “~/.config/solana/id.json”

rpc_url: Option<String>

RPC Url

cache: String

Path to the cache file, defaults to “cache.json”

config: String

Path to the config file

all: bool

Unthaw all NFTs in the candy machine.

nft_mint: Option<String>

Address of the NFT to thaw.

candy_guard: Option<String>

Address of candy guard to update [defaults to cache value].

candy_machine: Option<String>

Address of candy machine to update [defaults to cache value].

destination: Option<String>

Address of the destination (treaury) account.

label: Option<String>

Candy guard group label.

use_cache: bool

Indicates to create/use a cache file for mint list.

timeout: Option<u64>

RPC timeout to retrieve the mint list (in seconds).

Thaw a NFT or all NFTs in a candy guard.



UnlockFunds

Fields

keypair: Option<String>

Path to the keypair file, uses Sol config or defaults to “~/.config/solana/id.json”

rpc_url: Option<String>

RPC Url

cache: String

Path to the cache file, defaults to “cache.json”

config: String

Path to the config file

candy_guard: Option<String>

Address of candy guard to update [defaults to cache value].

candy_machine: Option<String>

Address of candy machine to update [defaults to cache value].

destination: Option<String>

Address of the destination (treasury) account.

label: Option<String>

Candy guard group label.

Unlock treasury funds after freeze is turned off or expires.