Struct sugar_cli::common::nft_accounts::InitializeCandyMachine
source · pub struct InitializeCandyMachine {
pub candy_machine: Pubkey,
pub wallet: Pubkey,
pub authority: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for InitializeCandyMachine.
Fields
candy_machine: Pubkeywallet: Pubkeypayer: Pubkeysystem_program: Pubkeyrent: PubkeyTrait Implementations
sourceimpl ToAccountMetas for InitializeCandyMachine
impl ToAccountMetas for InitializeCandyMachine
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for InitializeCandyMachine
impl Send for InitializeCandyMachine
impl Sync for InitializeCandyMachine
impl Unpin for InitializeCandyMachine
impl UnwindSafe for InitializeCandyMachine