Struct sugar_cli::common::nft_accounts::RemoveCollection
source · pub struct RemoveCollection {
pub candy_machine: Pubkey,
pub authority: Pubkey,
pub collection_pda: Pubkey,
pub metadata: Pubkey,
pub mint: Pubkey,
pub collection_authority_record: Pubkey,
pub token_metadata_program: Pubkey,
}Expand description
Generated client accounts for RemoveCollection.
Fields
candy_machine: Pubkeycollection_pda: Pubkeymetadata: Pubkeymint: Pubkeytoken_metadata_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for RemoveCollection
impl BorshSerialize for RemoveCollection
sourceimpl ToAccountMetas for RemoveCollection
impl ToAccountMetas for RemoveCollection
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for RemoveCollection
impl Send for RemoveCollection
impl Sync for RemoveCollection
impl Unpin for RemoveCollection
impl UnwindSafe for RemoveCollection