Struct sugar_cli::common::nft_accounts::SetCollection
source · pub struct SetCollection {
pub candy_machine: Pubkey,
pub authority: Pubkey,
pub collection_pda: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
pub rent: Pubkey,
pub metadata: Pubkey,
pub mint: Pubkey,
pub edition: Pubkey,
pub collection_authority_record: Pubkey,
pub token_metadata_program: Pubkey,
}Expand description
Generated client accounts for SetCollection.
Fields
candy_machine: Pubkeycollection_pda: Pubkeypayer: Pubkeysystem_program: Pubkeyrent: Pubkeymetadata: Pubkeymint: Pubkeyedition: Pubkeytoken_metadata_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for SetCollection
impl BorshSerialize for SetCollection
sourceimpl ToAccountMetas for SetCollection
impl ToAccountMetas for SetCollection
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for SetCollection
impl Send for SetCollection
impl Sync for SetCollection
impl Unpin for SetCollection
impl UnwindSafe for SetCollection