pub struct AddConfigLines {
pub index: u32,
pub config_lines: Vec<ConfigLine>,
}Expand description
Instruction.
Fields
index: u32config_lines: Vec<ConfigLine>Trait Implementations
Sourceimpl BorshDeserialize for AddConfigLines
impl BorshDeserialize for AddConfigLines
Sourcefn deserialize(buf: &mut &[u8]) -> Result<AddConfigLines, Error>
fn deserialize(buf: &mut &[u8]) -> Result<AddConfigLines, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourceimpl BorshSerialize for AddConfigLines
impl BorshSerialize for AddConfigLines
Sourceimpl Discriminator for AddConfigLines
impl Discriminator for AddConfigLines
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for AddConfigLines
impl InstructionData for AddConfigLines