pub struct Initialize {
pub data: CandyMachineData,
}Expand description
Instruction.
Fields
data: CandyMachineDataTrait Implementations
Sourceimpl BorshDeserialize for Initializewhere
CandyMachineData: BorshDeserialize,
impl BorshDeserialize for Initializewhere
CandyMachineData: BorshDeserialize,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Initialize, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Initialize, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourceimpl BorshSerialize for Initializewhere
CandyMachineData: BorshSerialize,
impl BorshSerialize for Initializewhere
CandyMachineData: BorshSerialize,
Sourceimpl Discriminator for Initialize
impl Discriminator for Initialize
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for Initialize
impl InstructionData for Initialize