pub struct InitializeV2 {
pub data: CandyMachineData,
pub token_standard: u8,
}Expand description
Instruction.
Fields
data: CandyMachineDatatoken_standard: u8Trait Implementations
Sourceimpl BorshDeserialize for InitializeV2
impl BorshDeserialize for InitializeV2
Sourcefn deserialize(buf: &mut &[u8]) -> Result<InitializeV2, Error>
fn deserialize(buf: &mut &[u8]) -> Result<InitializeV2, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourceimpl BorshSerialize for InitializeV2
impl BorshSerialize for InitializeV2
Sourceimpl Discriminator for InitializeV2
impl Discriminator for InitializeV2
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for InitializeV2
impl InstructionData for InitializeV2