pub struct Program { /* private fields */ }Expand description
Program is the primary client handle to be used to build and send requests.
Implementations
Sourceimpl Program
impl Program
pub fn payer(&self) -> Pubkey
Sourcepub fn request(&self) -> RequestBuilder<'_>
pub fn request(&self) -> RequestBuilder<'_>
Returns a request builder.
Sourcepub fn state_request(&self) -> RequestBuilder<'_>
pub fn state_request(&self) -> RequestBuilder<'_>
Returns a request builder for program state.
Sourcepub fn account<T>(&self, address: Pubkey) -> Result<T, ClientError>where
T: AccountDeserialize,
pub fn account<T>(&self, address: Pubkey) -> Result<T, ClientError>where
T: AccountDeserialize,
Returns the account at the given address.
Sourcepub fn accounts<T>(
&self,
filters: Vec<RpcFilterType>,
) -> Result<Vec<(Pubkey, T)>, ClientError>where
T: AccountDeserialize + Discriminator,
pub fn accounts<T>(
&self,
filters: Vec<RpcFilterType>,
) -> Result<Vec<(Pubkey, T)>, ClientError>where
T: AccountDeserialize + Discriminator,
Returns all program accounts of the given type matching the given filters
Sourcepub fn accounts_lazy<T>(
&self,
filters: Vec<RpcFilterType>,
) -> Result<ProgramAccountsIterator<T>, ClientError>where
T: AccountDeserialize + Discriminator,
pub fn accounts_lazy<T>(
&self,
filters: Vec<RpcFilterType>,
) -> Result<ProgramAccountsIterator<T>, ClientError>where
T: AccountDeserialize + Discriminator,
Returns all program accounts of the given type matching the given filters as an iterator Deserialization is executed lazily
pub fn state<T>(&self) -> Result<T, ClientError>where
T: AccountDeserialize,
pub fn rpc(&self) -> RpcClient
pub fn id(&self) -> Pubkey
pub fn on<T>(
&self,
f: impl Fn(&EventContext, T) + Send + 'static,
) -> Result<PubsubClientSubscription<Response<RpcLogsResponse>>, ClientError>where
T: Event + BorshDeserialize,