pub struct ConfigData {Show 15 fields
pub token_standard: TokenStandard,
pub number: u64,
pub symbol: String,
pub seller_fee_basis_points: u16,
pub is_mutable: bool,
pub is_sequential: bool,
pub creators: Vec<Creator>,
pub upload_method: UploadMethod,
pub rule_set: Option<Pubkey>,
pub aws_config: Option<AwsConfig>,
pub nft_storage_auth_token: Option<String>,
pub shdw_storage_account: Option<String>,
pub pinata_config: Option<PinataConfig>,
pub hidden_settings: Option<HiddenSettings>,
pub guards: Option<CandyGuardData>,
}Fields
token_standard: TokenStandardToken standard.
number: u64Number of assets available
symbol: StringSymbol for the asset
seller_fee_basis_points: u16Secondary sales royalty basis points (0-10000)
is_mutable: boolIndicates if the asset is mutable or not (default yes)
is_sequential: boolIndicates whether the index generation is sequential or not
creators: Vec<Creator>List of creators
upload_method: UploadMethodUpload method to use
rule_set: Option<Pubkey>aws_config: Option<AwsConfig>nft_storage_auth_token: Option<String>shdw_storage_account: Option<String>pinata_config: Option<PinataConfig>Hidden setttings
guards: Option<CandyGuardData>Guards configuration