#[repr(C)]pub struct Account {
pub lamports: u64,
pub data: Vec<u8>,
pub owner: Pubkey,
pub executable: bool,
pub rent_epoch: u64,
}Expand description
An Account with data that is stored on chain
Fields
lamports: u64lamports in the account
data: Vec<u8>data held in this account
owner: Pubkeythe program that owns this account. If executable, the program that loads this account.
executable: boolthis account’s data contains a loaded program (and is now read-only)
rent_epoch: u64the epoch at which this account will next owe rent
Implementations
Sourceimpl Account
impl Account
pub fn new(lamports: u64, space: usize, owner: &Pubkey) -> Account
pub fn new_ref( lamports: u64, space: usize, owner: &Pubkey, ) -> Rc<RefCell<Account>>
pub fn new_data<T>(
lamports: u64,
state: &T,
owner: &Pubkey,
) -> Result<Account, Box<ErrorKind>>where
T: Serialize,
pub fn new_ref_data<T>(
lamports: u64,
state: &T,
owner: &Pubkey,
) -> Result<RefCell<Account>, Box<ErrorKind>>where
T: Serialize,
pub fn new_data_with_space<T>(
lamports: u64,
state: &T,
space: usize,
owner: &Pubkey,
) -> Result<Account, Box<ErrorKind>>where
T: Serialize,
pub fn new_ref_data_with_space<T>(
lamports: u64,
state: &T,
space: usize,
owner: &Pubkey,
) -> Result<RefCell<Account>, Box<ErrorKind>>where
T: Serialize,
pub fn new_rent_epoch( lamports: u64, space: usize, owner: &Pubkey, rent_epoch: u64, ) -> Account
pub fn deserialize_data<T>(&self) -> Result<T, Box<ErrorKind>>where
T: DeserializeOwned,
pub fn serialize_data<T>(&mut self, state: &T) -> Result<(), Box<ErrorKind>>where
T: Serialize,