pub struct AssetInfo {
    pub asset_id: String,
    pub name: String,
    pub content: String,
    pub data_type: DataType,
    pub content_type: String,
}
Struct representing an asset ready for upload. An AssetInfo can represent a physical file, in which case the content will correspond to the name of the file; or an in-memory asset, in which case the content will correspond to the content of the asset.

For example, for image files, the content contains the path of the file on the file system. In the case of json metadata files, the content contains the string representation of the json metadata.

Fields

asset_id: String

Id of the asset in the cache.

name: String

Name (file name) of the asset.

content: String

Content of the asset - either a file path or the string representation of the content.

data_type: DataType

Type of the asset.

content_type: String

MIME content type.