Module process

Modules

system_instruction
Instructions and constructors for the system program.
system_program
The system native program.
sysvar
Access to special accounts with dynamically-updated data.

Structs

Client
Client defines the base configuration for building RPC clients to communicate with Anchor programs running on a Solana cluster. It’s primary use is to build a Program client via the program method.
CommitmentConfig
Keypair
A vanilla Ed25519 key pair
Program
Program is the primary client handle to be used to build and send requests.
Pubkey
The address of a Solana account.
Signature
Transaction
An atomically-commited sequence of instructions.
WithdrawArgs

Enums

CommitmentLevel
An attribute of a slot. It describes how finalized a block is at some point in time. For example, a slot is said to be at the max level immediately after the cluster recognizes the block at that slot as finalized. When querying the ledger state, use lower levels of commitment to report progress and higher levels to ensure state changes will not be rolled back.

Constants

LAMPORTS_PER_MLN
There are 10^9 lamports in one MLN

Traits

Signer
The Signer trait declares operations that all digital signature providers must support. It is the primary interface by which signers are specified in Transaction signing interfaces

Functions

process_withdraw