pub struct ConfigData {
Show 13 fields pub number: u64, pub symbol: String, pub seller_fee_basis_points: u16, pub is_mutable: bool, pub is_sequential: bool, pub creators: Vec<Creator>, pub upload_method: UploadMethod, pub aws_config: Option<AwsConfig>, pub nft_storage_auth_token: Option<String>, pub shdw_storage_account: Option<String>, pub pinata_config: Option<PinataConfig>, pub hidden_settings: Option<HiddenSettings>, pub guards: Option<CandyGuardData>,
}

Fields

number: u64

Number of assets available

symbol: String

Symbol for the asset

seller_fee_basis_points: u16

Secondary sales royalty basis points (0-10000)

is_mutable: bool

Indicates if the asset is mutable or not (default yes)

is_sequential: bool

Indicates whether the index generation is sequential or not

creators: Vec<Creator>

List of creators

upload_method: UploadMethod

Upload method to use

aws_config: Option<AwsConfig>nft_storage_auth_token: Option<String>shdw_storage_account: Option<String>pinata_config: Option<PinataConfig>hidden_settings: Option<HiddenSettings>

Hidden setttings

guards: Option<CandyGuardData>

Guards configuration